==> healthrian_common_support-1.18.0.tar.gz: lib/src/filter/iir/iir_data.dart <==
import 'package:healthrian_common_support/healthrian_common_support.dart';

class IIRData {
  static const Map<Enum, NumeratorDenominator> freq250hz = {
    HighPass.hpf005: NumeratorDenominator(
      numerator: const [
        0.99911181807956051,
        -1.998223636159121,
        0.99911181807956051,
      ],
      denominator: const [
        1,
        -1.9982228472918415,
        0.9982244250264003,
      ],
    ),
    HighPass.hpf01: NumeratorDenominator(
      numerator: const [
        0.99822442502515751,
        -1.996448850050315,
        0.99822442502515751,
      ],
      denominator: const [
        1,
        -1.9964456973813389,
        0.99645200271929124,
      ],
    ),
    LowPass.lpf40: NumeratorDenominator(
      numerator: const [
        0.14532388387704243,
        0.29064776775408485,
        0.14532388387704243,
      ],
      denominator: const [
        1,
        -0.67102909077409623,
        0.25232462628226593,
      ],
    ),
    LowPass.lpf100: NumeratorDenominator(
      numerator: const [
        0.63894552515902237,
        1.2778910503180447,
        0.63894552515902237,
      ],
      denominator: const [
        1,
        1.1429805025399007,
        0.41280159809618855,
      ],
    ),
    BandStop.bsf50: NumeratorDenominator(
      numerator: const [
        0.97547839075053411,
        -0.60306925650899912,
        0.97547839075053411,
      ],
      denominator: const [
        1,
        -0.60306925650899912,
        0.9509567815010681,
      ],
    ),
    BandStop.bsf60: NumeratorDenominator(
      numerator: const [
        0.97547839075053411,
        -0.12254028942631784,
        0.97547839075053411,
      ],
      denominator: const [
        1,
        -0.12254028942631784,
        0.95095678150106822,
      ],
    ),
  };

  static const Map<Enum, NumeratorDenominator> freq500hz = {
    HighPass.hpf005: NumeratorDenominator(
      numerator: const [
        0.99911181807956051,
        -1.998223636159121,
        0.99911181807956051,
      ],
      denominator: const [
        1,
        -1.9982228472918415,
        0.9982244250264003,
      ],
    ),
    HighPass.hpf01: NumeratorDenominator(
      numerator: const [
        0.99822442502515751,
        -1.996448850050315,
        0.99822442502515751,
      ],
      denominator: const [
        1,
        -1.9964456973813389,
        0.99645200271929124,
      ],
    ),
    LowPass.lpf40: NumeratorDenominator(
      numerator: const [
        0.14532388387704243,
        0.29064776775408485,
        0.14532388387704243,
      ],
      denominator: const [
        1,
        -0.67102909077409623,
        0.25232462628226593,
      ],
    ),
    LowPass.lpf100: NumeratorDenominator(
      numerator: const [
        0.63894552515902237,
        1.2778910503180447,
        0.63894552515902237,
      ],
      denominator: const [
        1,
        1.1429805025399007,
        0.41280159809618855,
      ],
    ),
    BandStop.bsf50: NumeratorDenominator(
      numerator: const [
        0.97547839075053411,
        -0.60306925650899912,
        0.97547839075053411,
      ],
      denominator: const [
        1,
        -0.60306925650899912,
        0.9509567815010681,
      ],
    ),
    BandStop.bsf60: NumeratorDenominator(
      numerator: const [
        0.97547839075053411,
        -0.12254028942631784,
        0.97547839075053411,
      ],
      denominator: const [
        1,
        -0.12254028942631784,
        0.95095678150106822,
      ],
    ),
  };
}

class NumeratorDenominator {
  const NumeratorDenominator({
    required this.numerator,
    required this.denominator,
  });

  final List<double> numerator;
  final List<double> denominator;
}

==> healthrian_common_support-1.31.4.tar.gz: lib/src/filter/iir/iir_data.dart <==
import 'package:healthrian_common_support/healthrian_common_support.dart';

class IIRData {
  static const Map<Enum, NumeratorDenominator> freq250hz = {
    HighPass.hpf05: NumeratorDenominator(
      numerator: const [
        0.99911181807956051,
        -1.998223636159121,
        0.99911181807956051,
      ],
      denominator: const [
        1,
        -1.9982228472918415,
        0.9982244250264003,
      ],
    ),
    HighPass.hpf01: NumeratorDenominator(
      numerator: const [
        0.99822442502515751,
        -1.996448850050315,
        0.99822442502515751,
      ],
      denominator: const [
        1,
        -1.9964456973813389,
        0.99645200271929124,
      ],
    ),
    LowPass.lpf40: NumeratorDenominator(
      numerator: const [
        0.14532388387704243,
        0.29064776775408485,
        0.14532388387704243,
      ],
      denominator: const [
        1,
        -0.67102909077409623,
        0.25232462628226593,
      ],
    ),
    LowPass.lpf100: NumeratorDenominator(
      numerator: const [
        0.63894552515902237,
        1.2778910503180447,
        0.63894552515902237,
      ],
      denominator: const [
        1,
        1.1429805025399007,
        0.41280159809618855,
      ],
    ),
    BandStop.bsf50: NumeratorDenominator(
      numerator: const [
        0.97547839075053411,
        -0.60306925650899912,
        0.97547839075053411,
      ],
      denominator: const [
        1,
        -0.60306925650899912,
        0.9509567815010681,
      ],
    ),
    BandStop.bsf60: NumeratorDenominator(
      numerator: const [
        0.97547839075053411,
        -0.12254028942631784,
        0.97547839075053411,
      ],
      denominator: const [
        1,
        -0.12254028942631784,
        0.95095678150106822,
      ],
    ),
  };

  static const Map<Enum, NumeratorDenominator> freq500hz = {
    HighPass.hpf05: NumeratorDenominator(
      numerator: const [
        0.99556697201764721,
        -1.9911339440352944,
        0.99556697201764721,
      ],
      denominator: const [
        1,
        -1.9911142922016536 ,
        0.99115359586893548,
      ],
    ),
    HighPass.hpf01: NumeratorDenominator(
      numerator: const [
        0.99911181807956051,
        -1.998223636159121,
        0.99911181807956051,
      ],
      denominator: const [
        1,
        -1.9982228472918415,
        0.9982244250264003,
      ],
    ),
    LowPass.lpf40: NumeratorDenominator(
      numerator: const [
        0.046131802093312926,
        0.092263604186625853,
        0.046131802093312926,
      ],
      denominator: const [
        1,
        -1.3072850288493234,
        0.49181223722257528,
      ],
    ),
    LowPass.lpf100: NumeratorDenominator(
      numerator: const [
        0.20657208382614792 ,
        0.41314416765229584,
        0.20657208382614792,
      ],
      denominator: const [
        1,
        -0.36952737735124147,
        0.19581571265583314,
      ],
    ),
    BandStop.bsf50: NumeratorDenominator(
      numerator: const [
        0.97547839075053411,
        -0.60306925650899912,
        0.97547839075053411,
      ],
      denominator: const [
        1,
        -0.60306925650899912,
        0.9509567815010681,
      ],
    ),
    BandStop.bsf60: NumeratorDenominator(
      numerator: const [
        0.97547839075053411,
        -1.4226355707285232,
        0.97547839075053411,
      ],
      denominator: const [
        1,
        -1.422635570728523,
        0.9509567815010681,
      ],
    ),
  };
}

class NumeratorDenominator {
  const NumeratorDenominator({
    required this.numerator,
    required this.denominator
  });

  final List<double> numerator;
  final List<double> denominator;
}
